NLSL: bincom.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Modules | Variables
bincom.f90 File Reference

Go to the source code of this file.

## Modules
module | bincom

## Variables
integer, parameter | bincom::nb =2*(mxlval+8)+2
integer, parameter | bincom::nbncf =nb*(nb+1)+1
integer, dimension(nb), save | bincom::bncfx
double precision, dimension(nbncf), save | bincom::bncf